@@ -70,6 +70,15 @@ commands = {
     'alike': {
         'aliases': {'一样'},
         'func': alike
+    },
+    'roll': {
+        'aliases': {'滚'},
+        'func': roll
+    },
+    'play_game': {
+        'aliases': {'玩游戏', '来玩游戏'},
+        'func': play_game,
+        'convert': False
     }
 }
 
